@@ -167,7 +167,7 @@ proc sortModulePerLoadedAndDepOrder {modlist {nporeq 0} {loading 0}} {
    # sort per loaded order
    set sortlist {}
    if {[llength $modlist] > 0} {
-      foreach lmmod [getLoadedModuleList] {
+      foreach lmmod [getLoadedModulePropertyList name] {
          if {$lmmod in $modlist} {
             lappend sortlist $lmmod
          }
@@ -192,6 +192,7 @@ proc sortModulePerLoadedAndDepOrder {modlist {nporeq 0} {loading 0}} {
       set mod [lindex $sortlist $i]
       set jmin $imax
 
+      ##nagelfar ignore #4 Suspicious variable name
       if {[info exists ${reqListVar}($mod)]} {
          # goes over all dependent modules to find the first one in the loaded
          # order list located after requiring mod
@@ -305,6 +306,7 @@ proc getDirectDependentList {mod {strong 0} {nporeq 0} {loading 0}\
       set reqListVar ::g_moduleDepend
    }
 
+   ##nagelfar ignore #2 Suspicious variable name
    if {[info exists ${depListVar}($mod)]} {
       foreach depmod [set ${depListVar}($mod)] {
          set add 1
@@ -313,6 +315,7 @@ proc getDirectDependentList {mod {strong 0} {nporeq 0} {loading 0}\
          # mods from a dependent list (composed of optional parts) are part
          # of the search, which means mod is not optional but strong dependent
          if {$strong && [llength $depmod] > 1} {
+            ##nagelfar ignore Suspicious variable name
             foreach lmmodlist [set ${reqListVar}([lindex $depmod 0])] {
                if {$mod in $lmmodlist} {
                   foreach lmmod $lmmodlist {
@@ -336,7 +339,7 @@ proc getDirectDependentList {mod {strong 0} {nporeq 0} {loading 0}\
 
    # take currently loading modules into account if asked
    if {$loading} {
-      set modlist [getLoadedModuleList]
+      set modlist [getLoadedModulePropertyList name]
       defineModEqProc [isIcase] [getConf extended_default] 1
       # reverse list to get closest match if returning lastly loaded module
       if {[getConf unload_match_order] eq {returnlast}} {
@@ -534,15 +537,17 @@ proc pushSettings {} {
       g_stateFunctions g_Functions g_stateCompletes g_Completes\
       g_newXResources g_delXResources g_loadedModules g_loadedModuleFiles\
       g_loadedModuleVariant g_loadedModuleConflict g_loadedModulePrereq\
-      g_loadedModuleAltname g_loadedModuleAutoAltname\
+      g_loadedModulesRefresh g_loadedModuleAltname g_loadedModuleAutoAltname\
       g_loadedModuleAliasAltname g_moduleDepend g_dependHash\
       g_moduleNPODepend g_dependNPOHash g_prereqViolation\
       g_prereqNPOViolation g_conflictViolation g_moduleUnmetDep\
       g_unmetDepHash g_moduleEval g_moduleHiddenEval} {
+      ##nagelfar ignore Suspicious variable name
       lappend ::g_SAVE_$var [array get ::$var]
    }
    # save non-array variable and indication if it was set
    foreach var {g_changeDir g_stdoutPuts g_prestdoutPuts g_return_text} {
+      ##nagelfar ignore #4 Suspicious variable name
       if {[info exists ::$var]} {
          lappend ::g_SAVE_$var [list 1 [set ::$var]]
       } else {
@@ -559,11 +564,12 @@ proc popSettings {} {
       g_newXResources g_delXResources g_changeDir g_stdoutPuts\
       g_prestdoutPuts g_return_text g_loadedModules g_loadedModuleFiles\
       g_loadedModuleVariant g_loadedModuleConflict g_loadedModulePrereq\
-      g_loadedModuleAltname g_loadedModuleAutoAltname\
+      g_loadedModulesRefresh g_loadedModuleAltname g_loadedModuleAutoAltname\
       g_loadedModuleAliasAltname g_moduleDepend g_dependHash\
       g_moduleNPODepend g_dependNPOHash g_prereqViolation\
       g_prereqNPOViolation g_conflictViolation g_moduleUnmetDep\
       g_unmetDepHash g_moduleEval g_moduleHiddenEval} {
+      ##nagelfar ignore Suspicious variable name
       set ::g_SAVE_$var [lrange [set ::g_SAVE_$var] 0 end-1]
    }
    reportDebug "previously saved settings flushed (#$flushedid)"
@@ -574,12 +580,13 @@ proc restoreSettings {} {
       g_stateFunctions g_Functions g_stateCompletes g_Completes\
       g_newXResources g_delXResources g_loadedModules g_loadedModuleFiles\
       g_loadedModuleVariant g_loadedModuleConflict g_loadedModulePrereq\
-      g_loadedModuleAltname g_loadedModuleAutoAltname\
+      g_loadedModulesRefresh g_loadedModuleAltname g_loadedModuleAutoAltname\
       g_loadedModuleAliasAltname g_moduleDepend g_dependHash\
       g_moduleNPODepend g_dependNPOHash g_prereqViolation\
       g_prereqNPOViolation g_conflictViolation g_moduleUnmetDep\
       g_unmetDepHash g_moduleEval g_moduleHiddenEval} {
       # clear current $var arrays
+      ##nagelfar ignore #5 Suspicious variable name
       if {[info exists ::$var]} {
          unset ::$var
          array set ::$var {}
@@ -600,6 +607,7 @@ proc restoreSettings {} {
    }
    # restore non-array variable if it was set
    foreach var {g_changeDir g_stdoutPuts g_prestdoutPuts g_return_text} {
+      ##nagelfar ignore #6 Suspicious variable name
       if {[info exists ::$var]} {
          unset ::$var
       }
@@ -613,7 +621,7 @@ proc restoreSettings {} {
 }
 
 # load modules passed as args designated as requirement
-proc loadRequirementModuleList {tag_list args} {
+proc loadRequirementModuleList {tryload optional tag_list args} {
    set ret 0
    set prereqloaded 0
 
@@ -635,11 +643,11 @@ proc loadRequirementModuleList {tag_list args} {
          set arg [lindex $args $i]
 
          # hold output of each evaluation until they are all done to drop
-         # those that failed if one succeed
+         # those that failed if one succeed or if optional
          set curholdid load-$i-$arg
          lappendState reportholdid $curholdid
-         if {[catch {set retlo [cmdModuleLoad reqlo 0 $tag_list $arg]}\
-            errorMsg]} {
+         if {[catch {set retlo [cmdModuleLoad reqlo 0 $tryload 0 $tag_list\
+            $arg]} errorMsg]} {
             # if an error is raised, release output and rethrow the error
             # (could be raised if no modulepath defined for instance)
             lpopState reportholdid
@@ -663,7 +671,9 @@ proc loadRequirementModuleList {tag_list args} {
                set holdidlist $newholdidlist
             }
          }
-         lappend holdidlist $curholdid report
+         # drop report if not loaded and optional
+         set action [expr {$prereqloaded || !$optional ? {report} : {drop}}]
+         lappend holdidlist $curholdid $action
       }
       # output held messages
       releaseHeldReport {*}$holdidlist
@@ -731,7 +741,7 @@ proc reloadModuleListLoadPhase {lmname isuaskedlist vrlist extrataglist\
       # if an auto set default was excluded, module spec need parsing
       lassign [parseModuleSpecification 0 $mod {*}$vr($mod)] modnamevr
       # reload module with user asked property and extra tags preserved
-      if {[cmdModuleLoad $context $isuasked($mod) $extratag($mod)\
+      if {[cmdModuleLoad $context $isuasked($mod) 0 0 $extratag($mod)\
          $modnamevr]} {
          set errMsg [string map [list _MOD_ [getModuleDesignation spec\
             $modnamevr]] $errmsgtpl]
